[pal-cvs 2887] [631] added calculator for payment, and hide creditcard view.

Back to archive index

svnno****@sourc***** svnno****@sourc*****
2007年 10月 16日 (火) 22:49:35 JST


Revision: 631
          http://svn.sourceforge.jp/cgi-bin/viewcvs.cgi?root=pal&view=rev&rev=631
Author:   shinsuke
Date:     2007-10-16 22:49:34 +0900 (Tue, 16 Oct 2007)

Log Message:
-----------
added calculator for payment, and hide creditcard view.

Modified Paths:
--------------
    pompei/portlets/pompei-core/trunk/dbflute/schema/project-schema-pompei.xml
    pompei/portlets/pompei-core/trunk/src/main/config/pompei.clay
    pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/PompeiConstants.java
    pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/bsbhv/BsPaymentMethodBhv.java
    pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/bsdao/BsPaymentMethodDao.java
    pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/bsentity/BsPaymentMethod.java
    pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/bsentity/dbmeta/PaymentMethodDbm.java
    pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/cbean/cq/bs/AbstractBsPaymentMethodCQ.java
    pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/cbean/cq/bs/BsPaymentMethodCQ.java
    pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/cbean/cq/ciq/PaymentMethodCIQ.java
    pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/fee/impl/DefaultDeliveryMethodCalculator.java
    pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/web/user/checkout/CheckoutConfirmAction.java
    pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/web/user/checkout/PaymentSelectAction.java
    pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/web/user/checkout/PaymentSelectPage.java
    pompei/portlets/pompei-core/trunk/src/main/resources/appMessages.properties
    pompei/portlets/pompei-core/trunk/src/main/resources/fee.dicon
    pompei/portlets/pompei-core/trunk/src/main/webapp/WEB-INF/db/create_table.sql
    pompei/portlets/pompei-core/trunk/src/main/webapp/view/user/checkout/paymentSelect.html

Added Paths:
-----------
    pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/fee/FeeCalculator.java
    pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/fee/impl/BankPaymentCalculator.java
    pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/fee/impl/CashOnDeliveryPaymentCalculator.java

Removed Paths:
-------------
    pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/fee/DeliveryMethodCalculator.java


-------------- next part --------------
Modified: pompei/portlets/pompei-core/trunk/dbflute/schema/project-schema-pompei.xml
===================================================================
--- pompei/portlets/pompei-core/trunk/dbflute/schema/project-schema-pompei.xml	2007-10-16 07:54:33 UTC (rev 630)
+++ pompei/portlets/pompei-core/trunk/dbflute/schema/project-schema-pompei.xml	2007-10-16 13:49:34 UTC (rev 631)
@@ -705,9 +705,11 @@
             primaryKey="true" required="true" type="INTEGER"/>
         <column dbType="VARCHAR" javaType="String" name="CODE"
             required="true" size="16" type="VARCHAR"/>
-        <column dbType="DECIMAL" javaType="java.math.BigDecimal"
-            name="FEE" required="true" size="14" type="DECIMAL"/>
+        <column dbType="VARCHAR" javaType="String" name="OBJECT_NAME"
+            required="true" size="128" type="VARCHAR"/>
         <column dbType="INTEGER" javaType="java.math.BigDecimal"
+            name="STATUS" required="true" type="INTEGER"/>
+        <column dbType="INTEGER" javaType="java.math.BigDecimal"
             name="SORT_ORDER" required="true" type="INTEGER"/>
         <column dbType="TIMESTAMP" javaType="java.sql.Timestamp"
             name="DATE_ADDED" required="true" type="TIMESTAMP"/>

Modified: pompei/portlets/pompei-core/trunk/src/main/config/pompei.clay
===================================================================
--- pompei/portlets/pompei-core/trunk/src/main/config/pompei.clay	2007-10-16 07:54:33 UTC (rev 630)
+++ pompei/portlets/pompei-core/trunk/src/main/config/pompei.clay	2007-10-16 13:49:34 UTC (rev 631)
@@ -3998,7 +3998,7 @@
 </table>
 <table alias="" name="PAYMENT_METHOD" remarks="" uid="1350e24:11525502e7d:-7e62">
 <table-description></table-description>
-<table-figure-bounds height="131" width="276" x="611" y="482"/>
+<table-figure-bounds height="131" width="276" x="645" y="462"/>
 <column-list>
 <column alias="" auto-increment="true" column-size="0" decimal-digits="0" default-value="" mandatory="true" name="PAYMENT_METHOD_ID" remarks="" uid="1350e24:11525502e7d:-7e60">
 <column-description></column-description>
@@ -4020,20 +4020,26 @@
 <variant precision-max="255" precision-min="1" precision-variable="%n" type-name-pattern="VARCHAR(%n) BINARY"/>
 </data-type>
 </column>
-<column alias="" auto-increment="false" column-size="14" decimal-digits="6" default-value="" mandatory="true" name="FEE" remarks="" uid="bf544c:1159961299e:-7fcc">
+<column alias="" auto-increment="false" column-size="128" decimal-digits="0" default-value="" mandatory="true" name="OBJECT_NAME" remarks="" uid="bf544c:1159961299e:-7fcc">
 <column-description></column-description>
-<data-type jdbc-type="3" name="DECIMAL" selected-variant-pattern="DECIMAL(%p, %s)">
-<variant precision-max="17" precision-min="0" precision-variable="%p" scale-max="128" scale-min="0" scale-variable="%s" type-name-pattern="DECIMAL(%p, %s)"/>
-<variant type-name-pattern="DECIMAL"/>
-<variant precision-max="17" precision-min="0" precision-variable="%n" type-name-pattern="DECIMAL(%n)"/>
-<variant precision-max="17" precision-min="0" precision-variable="%n" type-name-pattern="DECIMAL(%n) UNSIGNED"/>
-<variant precision-max="17" precision-min="0" precision-variable="%n" type-name-pattern="DECIMAL(%n) UNSIGNED ZEROFILL"/>
-<variant precision-max="17" precision-min="0" precision-variable="%n" type-name-pattern="DECIMAL(%n) ZEROFILL"/>
-<variant precision-max="17" precision-min="0" precision-variable="%p" scale-max="128" scale-min="0" scale-variable="%s" type-name-pattern="DECIMAL(%p, %s) UNSIGNED"/>
-<variant precision-max="17" precision-min="0" precision-variable="%p" scale-max="128" scale-min="0" scale-variable="%s" type-name-pattern="DECIMAL(%p, %s) UNSIGNED ZEROFILL"/>
-<variant precision-max="17" precision-min="0" precision-variable="%p" scale-max="128" scale-min="0" scale-variable="%s" type-name-pattern="DECIMAL(%p, %s) ZEROFILL"/>
+<data-type jdbc-type="12" literal-prefix="'" literal-suffix="'" name="VARCHAR" selected-variant-pattern="VARCHAR(%n)">
+<variant precision-max="255" precision-min="1" precision-variable="%n" type-name-pattern="VARCHAR(%n)"/>
+<variant precision-max="255" precision-min="1" precision-variable="%n" type-name-pattern="VARCHAR(%n) BINARY"/>
 </data-type>
 </column>
+<column alias="" auto-increment="false" column-size="0" decimal-digits="0" default-value="" mandatory="true" name="STATUS" remarks="" uid="1b80e60:115a7dda236:-7fce">
+<column-description></column-description>
+<data-type jdbc-type="4" name="INTEGER" selected-variant-pattern="INTEGER">
+<variant type-name-pattern="INTEGER"/>
+<variant precision-max="10" precision-min="0" precision-variable="%n" type-name-pattern="INTEGER(%n)"/>
+<variant precision-max="10" precision-min="0" precision-variable="%n" type-name-pattern="INTEGER(%n) UNSIGNED"/>
+<variant precision-max="10" precision-min="0" precision-variable="%n" type-name-pattern="INTEGER(%n) UNSIGNED ZEROFILL"/>
+<variant precision-max="10" precision-min="0" precision-variable="%n" type-name-pattern="INTEGER(%n) ZEROFILL"/>
+<variant type-name-pattern="INTEGER UNSIGNED"/>
+<variant type-name-pattern="INTEGER UNSIGNED ZEROFILL"/>
+<variant type-name-pattern="INTEGER ZEROFILL"/>
+</data-type>
+</column>
 <column alias="" auto-increment="false" column-size="0" decimal-digits="0" default-value="" mandatory="true" name="SORT_ORDER" remarks="" uid="1350e24:11525502e7d:-7e5e">
 <column-description></column-description>
 <data-type jdbc-type="4" name="INTEGER" selected-variant-pattern="INTEGER">

Modified: pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/PompeiConstants.java
===================================================================
--- pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/PompeiConstants.java	2007-10-16 07:54:33 UTC (rev 630)
+++ pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/PompeiConstants.java	2007-10-16 13:49:34 UTC (rev 631)
@@ -255,4 +255,8 @@
     public static final String SMTP_HOST = "smtpHost";
 
     public static final String DEFAULT_SMTP_HOST = "localhost";
+
+    public static final String SUB_TOTAL_PRICE = PREFIX + "SubTotalPrice";
+
+    public static final String TAX = PREFIX + "Tax";
 }

Modified: pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/bsbhv/BsPaymentMethodBhv.java
===================================================================
--- pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/bsbhv/BsPaymentMethodBhv.java	2007-10-16 07:54:33 UTC (rev 630)
+++ pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/bsbhv/BsPaymentMethodBhv.java	2007-10-16 13:49:34 UTC (rev 631)
@@ -30,7 +30,7 @@
  *     PAYMENT_METHOD_ID
  * 
  * [column-property]
- *     PAYMENT_METHOD_ID, CODE, FEE, SORT_ORDER, DATE_ADDED, LAST_MODIFIED
+ *     PAYMENT_METHOD_ID, CODE, OBJECT_NAME, STATUS, SORT_ORDER, DATE_ADDED, LAST_MODIFIED
  * 
  * [foreign-property]
  *     
@@ -934,7 +934,8 @@
 
         if (names.contains("paymentMethodId")) { destinationMyEntity.setPaymentMethodId(sourceMyEntity.getPaymentMethodId()); }
         if (names.contains("code")) { destinationMyEntity.setCode(sourceMyEntity.getCode()); }
-        if (names.contains("fee")) { destinationMyEntity.setFee(sourceMyEntity.getFee()); }
+        if (names.contains("objectName")) { destinationMyEntity.setObjectName(sourceMyEntity.getObjectName()); }
+        if (names.contains("status")) { destinationMyEntity.setStatus(sourceMyEntity.getStatus()); }
         if (names.contains("sortOrder")) { destinationMyEntity.setSortOrder(sourceMyEntity.getSortOrder()); }
         if (names.contains("dateAdded")) { destinationMyEntity.setDateAdded(sourceMyEntity.getDateAdded()); }
         if (names.contains("lastModified")) { destinationMyEntity.setLastModified(sourceMyEntity.getLastModified()); }

Modified: pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/bsdao/BsPaymentMethodDao.java
===================================================================
--- pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/bsdao/BsPaymentMethodDao.java	2007-10-16 07:54:33 UTC (rev 630)
+++ pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/bsdao/BsPaymentMethodDao.java	2007-10-16 13:49:34 UTC (rev 631)
@@ -11,7 +11,7 @@
  *     PAYMENT_METHOD_ID
  * 
  * [column-property]
- *     PAYMENT_METHOD_ID, CODE, FEE, SORT_ORDER, DATE_ADDED, LAST_MODIFIED
+ *     PAYMENT_METHOD_ID, CODE, OBJECT_NAME, STATUS, SORT_ORDER, DATE_ADDED, LAST_MODIFIED
  * 
  * [foreign-property]
  *     
@@ -51,7 +51,7 @@
     public int getCountAll();
 
     /** SQL-Annotation for getListAll(). */
-    public static final String getListAll_SQL = "select PAYMENT_METHOD_ID, CODE, FEE, SORT_ORDER, DATE_ADDED, LAST_MODIFIED from PAYMENT_METHOD";
+    public static final String getListAll_SQL = "select PAYMENT_METHOD_ID, CODE, OBJECT_NAME, STATUS, SORT_ORDER, DATE_ADDED, LAST_MODIFIED from PAYMENT_METHOD";
 
     /**
      * Get list as all.
@@ -61,7 +61,7 @@
     public java.util.List<PaymentMethod> getListAll();
 
     /** SQL-Annotation for getEntity(). */
-    public static final String getEntity_SQL = "select PAYMENT_METHOD_ID, CODE, FEE, SORT_ORDER, DATE_ADDED, LAST_MODIFIED from PAYMENT_METHOD where PAYMENT_METHOD.PAYMENT_METHOD_ID = /*paymentMethodId*/null";
+    public static final String getEntity_SQL = "select PAYMENT_METHOD_ID, CODE, OBJECT_NAME, STATUS, SORT_ORDER, DATE_ADDED, LAST_MODIFIED from PAYMENT_METHOD where PAYMENT_METHOD.PAYMENT_METHOD_ID = /*paymentMethodId*/null";
 
     /** Args-Annotation for getEntity(). */
     public static final String getEntity_ARGS = "paymentMethodId";

Modified: pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/bsentity/BsPaymentMethod.java
===================================================================
--- pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/cbean/cq/bs/AbstractBsPaymentMethodCQ.java	2007-10-16 07:54:33 UTC (rev 630)
+++ pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/cbean/cq/bs/AbstractBsPaymentMethodCQ.java	2007-10-16 13:49:34 UTC (rev 631)
@@ -367,110 +367,254 @@
 
     abstract protected ConditionValue getCValueCode();
       
-    /** Column db name of fee. */
-    protected static final String COL_FEE = "FEE";
+    /** Column db name of objectName. */
+    protected static final String COL_OBJECT_NAME = "OBJECT_NAME";
 
-    /** Column java name of fee. */
-    protected static final String J_Fee = "Fee";
+    /** Column java name of objectName. */
+    protected static final String J_ObjectName = "ObjectName";
 
-    /** Column uncapitalised java name of fee. */
-    protected static final String UJ_fee = "fee";
+    /** Column uncapitalised java name of objectName. */
+    protected static final String UJ_objectName = "objectName";
+    
+    /**
+     * Set the value of objectName using equal. { = }
+     * If the value is null or empty-string, this condition is ignored.
+     * 
+     * @param objectName The value of objectName as equal.
+     */
+    public void setObjectName_Equal(String objectName) {
+        registerObjectName(ConditionKey.CK_EQUAL, filterRemoveEmptyString(objectName));
+    }
+                  
+    /**
+     * Set the value of objectName using notEqual. { != }
+     * If the value is null or empty-string, this condition is ignored.
+     * 
+     * @param objectName The value of objectName as notEqual.
+     */
+    public void setObjectName_NotEqual(String objectName) {
+        registerObjectName(ConditionKey.CK_NOT_EQUAL, filterRemoveEmptyString(objectName));
+    }
             
     /**
-     * Set the value of fee using equal. { = }
+     * Set the value of objectName using greaterThan. { &gt; }
+     * If the value is null or empty-string, this condition is ignored.
      * 
-     * @param fee The value of fee as equal.
+     * @param objectName The value of objectName as greaterThan.
      */
-    public void setFee_Equal(java.math.BigDecimal fee) {
-        registerFee(ConditionKey.CK_EQUAL, fee);
+    public void setObjectName_GreaterThan(String objectName) {
+        registerObjectName(ConditionKey.CK_GREATER_THAN, filterRemoveEmptyString(objectName));
     }
             
     /**
-     * Set the value of fee using notEqual. { != }
+     * Set the value of objectName using lessThan. { &lt; }
+     * If the value is null or empty-string, this condition is ignored.
      * 
-     * @param fee The value of fee as notEqual.
+     * @param objectName The value of objectName as lessThan.
      */
-    public void setFee_NotEqual(java.math.BigDecimal fee) {
-        registerFee(ConditionKey.CK_NOT_EQUAL, fee);
+    public void setObjectName_LessThan(String objectName) {
+        registerObjectName(ConditionKey.CK_LESS_THAN, filterRemoveEmptyString(objectName));
     }
             
     /**
-     * Set the value of fee using greaterThan. { &gt; }
+     * Set the value of objectName using greaterEqual. { &gt;= }
+     * If the value is null or empty-string, this condition is ignored.
      * 
-     * @param fee The value of fee as greaterThan.
+     * @param objectName The value of objectName as greaterEqual.
      */
-    public void setFee_GreaterThan(java.math.BigDecimal fee) {
-        registerFee(ConditionKey.CK_GREATER_THAN, fee);
+    public void setObjectName_GreaterEqual(String objectName) {
+        registerObjectName(ConditionKey.CK_GREATER_EQUAL, filterRemoveEmptyString(objectName));
     }
             
     /**
-     * Set the value of fee using lessThan. { &lt; }
+     * Set the value of objectName using lessEqual. { &lt;= }
+     * If the value is null or empty-string, this condition is ignored.
      * 
-     * @param fee The value of fee as lessThan.
+     * @param objectName The value of objectName as lessEqual.
      */
-    public void setFee_LessThan(java.math.BigDecimal fee) {
-        registerFee(ConditionKey.CK_LESS_THAN, fee);
+    public void setObjectName_LessEqual(String objectName) {
+        registerObjectName(ConditionKey.CK_LESS_EQUAL, filterRemoveEmptyString(objectName));
     }
             
     /**
-     * Set the value of fee using greaterEqual. { &gt;= }
+     * Set the value of objectName using prefixSearch. { like 'xxx%' }
+     * If the value is null or empty-string, this condition is ignored.
      * 
-     * @param fee The value of fee as greaterEqual.
+     * @param objectName The value of objectName as prefixSearch.
      */
-    public void setFee_GreaterEqual(java.math.BigDecimal fee) {
-        registerFee(ConditionKey.CK_GREATER_EQUAL, fee);
+    public void setObjectName_PrefixSearch(String objectName) {
+        registerObjectName(ConditionKey.CK_PREFIX_SEARCH, filterRemoveEmptyString(objectName));
     }
             
     /**
-     * Set the value of fee using lessEqual. { &lt;= }
+     * Set the value of objectName using likeSearch. { like '%xxx%' }
+     * If the value is null or empty-string, this condition is ignored.
+     * You can invoke this method several times and the conditions are set up.
      * 
-     * @param fee The value of fee as lessEqual.
+     * @param objectName The value of objectName as likeSearch.
+     * @param likeSearchOption The option of like-search. (NotNull)
      */
-    public void setFee_LessEqual(java.math.BigDecimal fee) {
-        registerFee(ConditionKey.CK_LESS_EQUAL, fee);
+    public void setObjectName_LikeSearch(String objectName, jp.sf.pal.pompei.allcommon.cbean.coption.LikeSearchOption likeSearchOption) {
+        registerLikeSearchQuery(ConditionKey.CK_LIKE_SEARCH, filterRemoveEmptyString(objectName), getCValueObjectName(), COL_OBJECT_NAME, J_ObjectName, UJ_objectName, likeSearchOption);
     }
+            
+    /**
+     * Set the value of objectName using inScope. { in ('a', 'b') }
+     * If the element in the list is null or empty-string, the condition-element is ignored.
+     * 
+     * @param objectNameList The value of objectName as inScope.
+     */
+    public void setObjectName_InScope(java.util.List<String> objectNameList) {
+        registerObjectName(ConditionKey.CK_IN_SCOPE, filterRemoveEmptyStringFromList(objectNameList));
+    }
+
+    /**
+     * Set the value of objectName using inScope. { in ('a', 'b') }
+     * If the element in the list is null or empty-string, the condition-element is ignored.
+     * 
+     * @param objectName The value of objectName as inScope.
+     * @param inScopeOption The option of in-scope. (NotNull)
+     */
+    public void setObjectName_InScope(String objectName, jp.sf.pal.pompei.allcommon.cbean.coption.InScopeOption inScopeOption) {
+        registerInScopeQuery(ConditionKey.CK_IN_SCOPE, filterRemoveEmptyString(objectName), getCValueObjectName(), COL_OBJECT_NAME, J_ObjectName, UJ_objectName, inScopeOption);
+    }
+            
+    /**
+     * Set the value of objectName using notInScope. { not in ('a', 'b') }
+     * If the element in the list is null or empty-string, the condition-element is ignored.
+     * 
+     * @param objectNameList The value of objectName as notInScope.
+     */
+    public void setObjectName_NotInScope(java.util.List<String> objectNameList) {
+        registerObjectName(ConditionKey.CK_NOT_IN_SCOPE, filterRemoveEmptyStringFromList(objectNameList));
+    }
+                                                    
+    /**
+     * Register condition of objectName.
+     * 
+     * @param key Condition key. (NotNull)
+     * @param value The value of objectName. (Nullable)
+     */
+    protected void registerObjectName(ConditionKey key, Object value) {
+        registerQuery(key, value, getCValueObjectName(), COL_OBJECT_NAME, J_ObjectName, UJ_objectName);
+    }
+
+    /**
+     * Register inline condition of objectName.
+     * 
+     * @param key Condition key. (NotNull)
+     * @param value The value of objectName. (Nullable)
+     */
+    protected void registerInlineObjectName(ConditionKey key, Object value) {
+        registerInlineQuery(key, value, getCValueObjectName(), COL_OBJECT_NAME, J_ObjectName, UJ_objectName);
+    }
+
+    abstract protected ConditionValue getCValueObjectName();
+      
+    /** Column db name of status. */
+    protected static final String COL_STATUS = "STATUS";
+
+    /** Column java name of status. */
+    protected static final String J_Status = "Status";
+
+    /** Column uncapitalised java name of status. */
+    protected static final String UJ_status = "status";
+            
+    /**
+     * Set the value of status using equal. { = }
+     * 
+     * @param status The value of status as equal.
+     */
+    public void setStatus_Equal(java.math.BigDecimal status) {
+        registerStatus(ConditionKey.CK_EQUAL, status);
+    }
+            
+    /**
+     * Set the value of status using notEqual. { != }
+     * 
+     * @param status The value of status as notEqual.
+     */
+    public void setStatus_NotEqual(java.math.BigDecimal status) {
+        registerStatus(ConditionKey.CK_NOT_EQUAL, status);
+    }
+            
+    /**
+     * Set the value of status using greaterThan. { &gt; }
+     * 
+     * @param status The value of status as greaterThan.
+     */
+    public void setStatus_GreaterThan(java.math.BigDecimal status) {
+        registerStatus(ConditionKey.CK_GREATER_THAN, status);
+    }
+            
+    /**
+     * Set the value of status using lessThan. { &lt; }
+     * 
+     * @param status The value of status as lessThan.
+     */
+    public void setStatus_LessThan(java.math.BigDecimal status) {
+        registerStatus(ConditionKey.CK_LESS_THAN, status);
+    }
+            
+    /**
+     * Set the value of status using greaterEqual. { &gt;= }
+     * 
+     * @param status The value of status as greaterEqual.
+     */
+    public void setStatus_GreaterEqual(java.math.BigDecimal status) {
+        registerStatus(ConditionKey.CK_GREATER_EQUAL, status);
+    }
+            
+    /**
+     * Set the value of status using lessEqual. { &lt;= }
+     * 
+     * @param status The value of status as lessEqual.
+     */
+    public void setStatus_LessEqual(java.math.BigDecimal status) {
+        registerStatus(ConditionKey.CK_LESS_EQUAL, status);
+    }
                   
     /**
-     * Set the value of fee using inScope. { in (a, b) }
+     * Set the value of status using inScope. { in (a, b) }
      * If the element in the list is null or empty-string, the condition-element is ignored.
      * 
-     * @param feeList The value of fee as inScope.
+     * @param statusList The value of status as inScope.
      */
-    public void setFee_InScope(java.util.List<java.math.BigDecimal> feeList) {
-        registerFee(ConditionKey.CK_IN_SCOPE, feeList);
+    public void setStatus_InScope(java.util.List<java.math.BigDecimal> statusList) {
+        registerStatus(ConditionKey.CK_IN_SCOPE, statusList);
     }
             
     /**
-     * Set the value of fee using notInScope. { not in (a, b) }
+     * Set the value of status using notInScope. { not in (a, b) }
      * If the element in the list is null or empty-string, the condition-element is ignored.
      * 
-     * @param feeList The value of fee as notInScope.
+     * @param statusList The value of status as notInScope.
      */
-    public void setFee_NotInScope(java.util.List<java.math.BigDecimal> feeList) {
-        registerFee(ConditionKey.CK_NOT_IN_SCOPE, feeList);
+    public void setStatus_NotInScope(java.util.List<java.math.BigDecimal> statusList) {
+        registerStatus(ConditionKey.CK_NOT_IN_SCOPE, statusList);
     }
                                                 
     /**
-     * Register condition of fee.
+     * Register condition of status.
      * 
      * @param key Condition key. (NotNull)
-     * @param value The value of fee. (Nullable)
+     * @param value The value of status. (Nullable)
      */
-    protected void registerFee(ConditionKey key, Object value) {
-        registerQuery(key, value, getCValueFee(), COL_FEE, J_Fee, UJ_fee);
+    protected void registerStatus(ConditionKey key, Object value) {
+        registerQuery(key, value, getCValueStatus(), COL_STATUS, J_Status, UJ_status);
     }
 
     /**
-     * Register inline condition of fee.
+     * Register inline condition of status.
      * 
      * @param key Condition key. (NotNull)
-     * @param value The value of fee. (Nullable)
+     * @param value The value of status. (Nullable)
      */
-    protected void registerInlineFee(ConditionKey key, Object value) {
-        registerInlineQuery(key, value, getCValueFee(), COL_FEE, J_Fee, UJ_fee);
+    protected void registerInlineStatus(ConditionKey key, Object value) {
+        registerInlineQuery(key, value, getCValueStatus(), COL_STATUS, J_Status, UJ_status);
     }
 
-    abstract protected ConditionValue getCValueFee();
+    abstract protected ConditionValue getCValueStatus();
       
     /** Column db name of sortOrder. */
     protected static final String COL_SORT_ORDER = "SORT_ORDER";

Modified: pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/cbean/cq/bs/BsPaymentMethodCQ.java
===================================================================
--- pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/cbean/cq/ciq/PaymentMethodCIQ.java	2007-10-16 07:54:33 UTC (rev 630)
+++ pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/cbean/cq/ciq/PaymentMethodCIQ.java	2007-10-16 13:49:34 UTC (rev 631)
@@ -111,14 +111,22 @@
 
                                                         
     // /- - - - - - - - - - - - - - - - - - - - - - -
-    //   Column = [FEE]
+    //   Column = [OBJECT_NAME]
     // - - - - - - - - -/
-    protected ConditionValue getCValueFee() {
-        return _myCQ.getFee();
+    protected ConditionValue getCValueObjectName() {
+        return _myCQ.getObjectName();
     }
 
                                                         
     // /- - - - - - - - - - - - - - - - - - - - - - -
+    //   Column = [STATUS]
+    // - - - - - - - - -/
+    protected ConditionValue getCValueStatus() {
+        return _myCQ.getStatus();
+    }
+
+                                                        
+    // /- - - - - - - - - - - - - - - - - - - - - - -
     //   Column = [SORT_ORDER]
     // - - - - - - - - -/
     protected ConditionValue getCValueSortOrder() {

Deleted: pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/fee/DeliveryMethodCalculator.java
===================================================================
--- pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/fee/DeliveryMethodCalculator.java	2007-10-16 07:54:33 UTC (rev 630)
+++ pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/fee/DeliveryMethodCalculator.java	2007-10-16 13:49:34 UTC (rev 631)
@@ -1,13 +0,0 @@
-package jp.sf.pal.pompei.fee;
-
-import java.io.Serializable;
-import java.math.BigDecimal;
-import java.util.List;
-
-import jp.sf.pal.pompei.exentity.AddressBook;
-import jp.sf.pal.pompei.exentity.CustomerBasket;
-
-public interface DeliveryMethodCalculator extends Serializable {
-    public BigDecimal calculate(List<CustomerBasket> list,
-            AddressBook deliveryAddressBook);
-}

Copied: pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/fee/FeeCalculator.java (from rev 581, pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/fee/DeliveryMethodCalculator.java)
===================================================================
--- pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/fee/DeliveryMethodCalculator.java	2007-09-25 05:33:00 UTC (rev 581)
+++ pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/fee/FeeCalculator.java	2007-10-16 13:49:34 UTC (rev 631)
@@ -0,0 +1,14 @@
+package jp.sf.pal.pompei.fee;
+
+import java.io.Serializable;
+import java.math.BigDecimal;
+import java.util.List;
+import java.util.Map;
+
+import jp.sf.pal.pompei.exentity.AddressBook;
+import jp.sf.pal.pompei.exentity.CustomerBasket;
+
+public interface FeeCalculator extends Serializable {
+    public BigDecimal calculate(List<CustomerBasket> list,
+            AddressBook deliveryAddressBook, Map<String, Object> informationMap);
+}

Added: pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/fee/impl/BankPaymentCalculator.java
===================================================================
--- pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/fee/impl/BankPaymentCalculator.java	2007-10-16 07:54:33 UTC (rev 630)
+++ pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/fee/impl/BankPaymentCalculator.java	2007-10-16 13:49:34 UTC (rev 631)
@@ -0,0 +1,23 @@
+package jp.sf.pal.pompei.fee.impl;
+
+import java.math.BigDecimal;
+import java.util.List;
+import java.util.Map;
+
+import jp.sf.pal.pompei.exentity.AddressBook;
+import jp.sf.pal.pompei.exentity.CustomerBasket;
+import jp.sf.pal.pompei.fee.FeeCalculator;
+
+public class BankPaymentCalculator implements FeeCalculator {
+
+    /**
+     * 
+     */
+    private static final long serialVersionUID = 2210867873710022790L;
+
+    public BigDecimal calculate(List<CustomerBasket> list,
+            AddressBook deliveryAddressBook, Map<String, Object> informationMap) {
+        return new BigDecimal(0);
+    }
+
+}


Property changes on: pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/fee/impl/BankPaymentCalculator.java
___________________________________________________________________
Name: svn:eol-style
   + native

Added: pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/fee/impl/CashOnDeliveryPaymentCalculator.java
===================================================================
--- pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/fee/impl/CashOnDeliveryPaymentCalculator.java	2007-10-16 07:54:33 UTC (rev 630)
+++ pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/fee/impl/CashOnDeliveryPaymentCalculator.java	2007-10-16 13:49:34 UTC (rev 631)
@@ -0,0 +1,23 @@
+package jp.sf.pal.pompei.fee.impl;
+
+import java.math.BigDecimal;
+import java.util.List;
+import java.util.Map;
+
+import jp.sf.pal.pompei.exentity.AddressBook;
+import jp.sf.pal.pompei.exentity.CustomerBasket;
+import jp.sf.pal.pompei.fee.FeeCalculator;
+
+public class CashOnDeliveryPaymentCalculator implements FeeCalculator {
+
+    /**
+     * 
+     */
+    private static final long serialVersionUID = 2769660903440943706L;
+
+    public BigDecimal calculate(List<CustomerBasket> list,
+            AddressBook deliveryAddressBook, Map<String, Object> informationMap) {
+        return new BigDecimal(300);
+    }
+
+}


Property changes on: pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/fee/impl/CashOnDeliveryPaymentCalculator.java
___________________________________________________________________
Name: svn:eol-style
   + native

Modified: pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/fee/impl/DefaultDeliveryMethodCalculator.java
===================================================================
--- pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/fee/impl/DefaultDeliveryMethodCalculator.java	2007-10-16 07:54:33 UTC (rev 630)
+++ pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/fee/impl/DefaultDeliveryMethodCalculator.java	2007-10-16 13:49:34 UTC (rev 631)
@@ -2,13 +2,13 @@
 
 import java.math.BigDecimal;
 import java.util.List;
+import java.util.Map;
 
 import jp.sf.pal.pompei.exentity.AddressBook;
 import jp.sf.pal.pompei.exentity.CustomerBasket;
-import jp.sf.pal.pompei.fee.DeliveryMethodCalculator;
+import jp.sf.pal.pompei.fee.FeeCalculator;
 
-public class DefaultDeliveryMethodCalculator implements
-        DeliveryMethodCalculator {
+public class DefaultDeliveryMethodCalculator implements FeeCalculator {
 
     /**
      * 
@@ -16,8 +16,8 @@
     private static final long serialVersionUID = 4448477278188463956L;
 
     public BigDecimal calculate(List<CustomerBasket> list,
-            AddressBook deliveryAddressBook) {
-        // TODO 自動生成されたメソッド・スタブ
+            AddressBook deliveryAddressBook, Map<String, Object> informationMap) {
+        // TODO
         return new BigDecimal(1000);
     }
 

Modified: pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/web/user/checkout/CheckoutConfirmAction.java
===================================================================
--- pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/web/user/checkout/CheckoutConfirmAction.java	2007-10-16 07:54:33 UTC (rev 630)
+++ pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/web/user/checkout/CheckoutConfirmAction.java	2007-10-16 13:49:34 UTC (rev 631)
@@ -24,7 +24,7 @@
 import jp.sf.pal.pompei.exentity.PaymentMethodDescription;
 import jp.sf.pal.pompei.exentity.ProductDescription;
 import jp.sf.pal.pompei.exentity.TaxRate;
-import jp.sf.pal.pompei.fee.DeliveryMethodCalculator;
+import jp.sf.pal.pompei.fee.FeeCalculator;
 import jp.sf.pal.pompei.service.CartService;
 import jp.sf.pal.pompei.service.CustomerService;
 import jp.sf.pal.pompei.service.DeliveryMethodSerivce;
@@ -178,6 +178,10 @@
                 new BigDecimal(100));
         getCheckoutConfirmPage().setTax(tax);
 
+        Map<String, Object> informationMap = new HashMap<String, Object>();
+        informationMap.put(PompeiConstants.SUB_TOTAL_PRICE, subTotalPrice);
+        informationMap.put(PompeiConstants.TAX, tax);
+
         // payment
         BigDecimal paymentMethodId = (BigDecimal) orderProcessMap
                 .get(PompeiConstants.PAYMENT_METHOD_ID);
@@ -196,11 +200,30 @@
         getCheckoutConfirmPage().setPaymentMethodName(pmd.getName());
 
         // payment fee
+        String paymentMethodObjectName = pmd.getPaymentMethod().getObjectName();
         BigDecimal paymentFee = PompeiConstants.DEFAULT_PAYMENT_FEE;
-        if (pmd.getPaymentMethod().getFee() != null) {
-            paymentFee = pmd.getPaymentMethod().getFee();
+        try {
+            FeeCalculator pmc = (FeeCalculator) getContainer().getComponent(
+                    paymentMethodObjectName);
+            paymentFee = pmc.calculate(baskets, deliveryAddressBook,
+                    informationMap);
+            getCheckoutConfirmPage().setPaymentFee(paymentFee);
+        } catch (ComponentNotFoundRuntimeException e) {
+            FacesMessageUtil
+                    .addErrorMessage("could.not.calculate.payment.fee.1");
+            //TODO logger
+            return UserInfoEditPage.class;
+        } catch (TooManyRegistrationRuntimeException e) {
+            FacesMessageUtil
+                    .addErrorMessage("could.not.calculate.payment.fee.2");
+            //TODO logger
+            return UserInfoEditPage.class;
+        } catch (CyclicReferenceRuntimeException e) {
+            FacesMessageUtil
+                    .addErrorMessage("could.not.calculate.payment.fee.3");
+            //TODO logger
+            return UserInfoEditPage.class;
         }
-        getCheckoutConfirmPage().setPaymentFee(paymentFee);
 
         // deliveryMethod
         BigDecimal deliveryMethodId = (BigDecimal) orderProcessMap
@@ -224,20 +247,24 @@
                 .getObjectName();
         BigDecimal deliveryPrice = PompeiConstants.DEFAULT_DELIVERY_PRICE;
         try {
-            DeliveryMethodCalculator dmc = (DeliveryMethodCalculator) getContainer()
-                    .getComponent(deliveryMethodObjectName);
-            deliveryPrice = dmc.calculate(baskets, deliveryAddressBook);
+            FeeCalculator dmc = (FeeCalculator) getContainer().getComponent(
+                    deliveryMethodObjectName);
+            deliveryPrice = dmc.calculate(baskets, deliveryAddressBook,
+                    informationMap);
             getCheckoutConfirmPage().setDeliveryPrice(deliveryPrice);
         } catch (ComponentNotFoundRuntimeException e) {
-            FacesMessageUtil.addErrorMessage("could.not.calculate.tax.1");
+            FacesMessageUtil
+                    .addErrorMessage("could.not.calculate.delivery.price.1");
             //TODO logger
             return UserInfoEditPage.class;
         } catch (TooManyRegistrationRuntimeException e) {
-            FacesMessageUtil.addErrorMessage("could.not.calculate.tax.2");
+            FacesMessageUtil
+                    .addErrorMessage("could.not.calculate.delivery.price.2");
             //TODO logger
             return UserInfoEditPage.class;
         } catch (CyclicReferenceRuntimeException e) {
-            FacesMessageUtil.addErrorMessage("could.not.calculate.tax.3");
+            FacesMessageUtil
+                    .addErrorMessage("could.not.calculate.delivery.price.3");
             //TODO logger
             return UserInfoEditPage.class;
         }

Modified: pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/web/user/checkout/PaymentSelectAction.java
===================================================================
--- pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/web/user/checkout/PaymentSelectAction.java	2007-10-16 07:54:33 UTC (rev 630)
+++ pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/web/user/checkout/PaymentSelectAction.java	2007-10-16 13:49:34 UTC (rev 631)
@@ -112,6 +112,16 @@
         getPaymentSelectPage().setPaymentMethodItems(
                 getPaymentMethodDxo().convert(pmd));
 
+        // check credit card
+        getPaymentSelectPage().setCreditcard(false);
+        for (PaymentMethodDescription paymentMethodDescription : pmd) {
+            if (PompeiConstants.CREDITCARD_PAYMENT_METHOD
+                    .equals(paymentMethodDescription.getPaymentMethod()
+                            .getCode())) {
+                getPaymentSelectPage().setCreditcard(true);
+            }
+        }
+
         // set card type
         List<CardTypeDescription> ctd = getCardTypeService()
                 .getCardTypeDescriptionList();

Modified: pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/web/user/checkout/PaymentSelectPage.java
===================================================================
--- pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/web/user/checkout/PaymentSelectPage.java	2007-10-16 07:54:33 UTC (rev 630)
+++ pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/web/user/checkout/PaymentSelectPage.java	2007-10-16 13:49:34 UTC (rev 631)
@@ -58,6 +58,8 @@
 
     private String description;
 
+    private boolean creditcard;
+
     /**
      * @return orderProcessId
      */
@@ -304,7 +306,8 @@
     /**
      * @param ccExpiresMonthItems 設定する ccExpiresMonthItems
      */
-    public void setCcExpiresMonthItems(List<Map<String, String>> ccExpiresMonthItems) {
+    public void setCcExpiresMonthItems(
+            List<Map<String, String>> ccExpiresMonthItems) {
         this.ccExpiresMonthItems = ccExpiresMonthItems;
     }
 
@@ -318,8 +321,23 @@
     /**
      * @param ccExpiresYearItems 設定する ccExpiresYearItems
      */
-    public void setCcExpiresYearItems(List<Map<String, String>> ccExpiresYearItems) {
+    public void setCcExpiresYearItems(
+            List<Map<String, String>> ccExpiresYearItems) {
         this.ccExpiresYearItems = ccExpiresYearItems;
     }
 
+    /**
+     * @return the credit card
+     */
+    public boolean isCreditcard() {
+        return creditcard;
+    }
+
+    /**
+     * @param creditcard the credit card to set
+     */
+    public void setCreditcard(boolean creditcard) {
+        this.creditcard = creditcard;
+    }
+
 }

Modified: pompei/portlets/pompei-core/trunk/src/main/resources/appMessages.properties
===================================================================
--- pompei/portlets/pompei-core/trunk/src/main/resources/appMessages.properties	2007-10-16 07:54:33 UTC (rev 630)
+++ pompei/portlets/pompei-core/trunk/src/main/resources/appMessages.properties	2007-10-16 13:49:34 UTC (rev 631)
@@ -83,9 +83,12 @@
 could.not.find.payment.method.in.checkoutconfirm=\u6307\u5b9a\u3055\u308c\u305f\u652f\u6255\u3044\u65b9\u6cd5\u304c\u6b63\u3057\u304f\u3042\u308a\u307e\u305b\u3093\u3002\u518d\u5ea6\u3001\u6ce8\u6587\u3057\u306a\u304a\u3057\u3066\u304f\u3060\u3055\u3044\u3002
 could.not.find.delivery.method.id.in.checkoutconfirm=\u6307\u5b9a\u3055\u308c\u305f\u914d\u9054\u65b9\u6cd5\u304c\u6b63\u3057\u304f\u3042\u308a\u307e\u305b\u3093\u3002\u518d\u5ea6\u3001\u6ce8\u6587\u3057\u306a\u304a\u3057\u3066\u304f\u3060\u3055\u3044\u3002
 could.not.find.delivery.method.in.checkoutconfirm=\u6307\u5b9a\u3055\u308c\u305f\u914d\u9054\u65b9\u6cd5\u304c\u6b63\u3057\u304f\u3042\u308a\u307e\u305b\u3093\u3002\u518d\u5ea6\u3001\u6ce8\u6587\u3057\u306a\u304a\u3057\u3066\u304f\u3060\u3055\u3044\u3002
-could.not.calculate.tax.1=\u6d88\u8cbb\u7a0e\u3092\u6d88\u8cbb\u7a0e\u3092\u8a08\u7b97\u3067\u304d\u307e\u305b\u3093\u3067\u3057\u305f\u3002\u518d\u5ea6\u3001\u8a66\u3057\u3066\u3082\u3001\u3053\u306e\u554f\u984c\u304c\u767a\u751f\u3059\u308b\u5834\u5408\u306b\u306f\u7ba1\u7406\u8005\u306b\u304a\u554f\u3044\u5408\u308f\u305b\u304f\u3060\u3055\u3044\u3002
-could.not.calculate.tax.2=\u6d88\u8cbb\u7a0e\u3092\u6d88\u8cbb\u7a0e\u3092\u8a08\u7b97\u3067\u304d\u307e\u305b\u3093\u3067\u3057\u305f\u3002\u518d\u5ea6\u3001\u8a66\u3057\u3066\u3082\u3001\u3053\u306e\u554f\u984c\u304c\u767a\u751f\u3059\u308b\u5834\u5408\u306b\u306f\u7ba1\u7406\u8005\u306b\u304a\u554f\u3044\u5408\u308f\u305b\u304f\u3060\u3055\u3044\u3002
-could.not.calculate.tax.3=\u6d88\u8cbb\u7a0e\u3092\u6d88\u8cbb\u7a0e\u3092\u8a08\u7b97\u3067\u304d\u307e\u305b\u3093\u3067\u3057\u305f\u3002\u518d\u5ea6\u3001\u8a66\u3057\u3066\u3082\u3001\u3053\u306e\u554f\u984c\u304c\u767a\u751f\u3059\u308b\u5834\u5408\u306b\u306f\u7ba1\u7406\u8005\u306b\u304a\u554f\u3044\u5408\u308f\u305b\u304f\u3060\u3055\u3044\u3002
+could.not.calculate.payment.fee.1=\u4ee3\u91d1\u5f15\u63db\u6599\u91d1\u3092\u8a08\u7b97\u3067\u304d\u307e\u305b\u3093\u3067\u3057\u305f\u3002\u518d\u5ea6\u3001\u8a66\u3057\u3066\u3082\u3001\u3053\u306e\u554f\u984c\u304c\u767a\u751f\u3059\u308b\u5834\u5408\u306b\u306f\u7ba1\u7406\u8005\u306b\u304a\u554f\u3044\u5408\u308f\u305b\u304f\u3060\u3055\u3044\u3002
+could.not.calculate.payment.fee.2=\u4ee3\u91d1\u5f15\u63db\u6599\u91d1\u3092\u8a08\u7b97\u3067\u304d\u307e\u305b\u3093\u3067\u3057\u305f\u3002\u518d\u5ea6\u3001\u8a66\u3057\u3066\u3082\u3001\u3053\u306e\u554f\u984c\u304c\u767a\u751f\u3059\u308b\u5834\u5408\u306b\u306f\u7ba1\u7406\u8005\u306b\u304a\u554f\u3044\u5408\u308f\u305b\u304f\u3060\u3055\u3044\u3002
+could.not.calculate.payment.fee.3=\u4ee3\u91d1\u5f15\u63db\u6599\u91d1\u3092\u8a08\u7b97\u3067\u304d\u307e\u305b\u3093\u3067\u3057\u305f\u3002\u518d\u5ea6\u3001\u8a66\u3057\u3066\u3082\u3001\u3053\u306e\u554f\u984c\u304c\u767a\u751f\u3059\u308b\u5834\u5408\u306b\u306f\u7ba1\u7406\u8005\u306b\u304a\u554f\u3044\u5408\u308f\u305b\u304f\u3060\u3055\u3044\u3002
+could.not.calculate.delivery.price.1=\u914d\u9001\u6599\u3092\u8a08\u7b97\u3067\u304d\u307e\u305b\u3093\u3067\u3057\u305f\u3002\u518d\u5ea6\u3001\u8a66\u3057\u3066\u3082\u3001\u3053\u306e\u554f\u984c\u304c\u767a\u751f\u3059\u308b\u5834\u5408\u306b\u306f\u7ba1\u7406\u8005\u306b\u304a\u554f\u3044\u5408\u308f\u305b\u304f\u3060\u3055\u3044\u3002
+could.not.calculate.delivery.price.2=\u914d\u9001\u6599\u3092\u8a08\u7b97\u3067\u304d\u307e\u305b\u3093\u3067\u3057\u305f\u3002\u518d\u5ea6\u3001\u8a66\u3057\u3066\u3082\u3001\u3053\u306e\u554f\u984c\u304c\u767a\u751f\u3059\u308b\u5834\u5408\u306b\u306f\u7ba1\u7406\u8005\u306b\u304a\u554f\u3044\u5408\u308f\u305b\u304f\u3060\u3055\u3044\u3002
+could.not.calculate.delivery.price.3=\u914d\u9001\u6599\u3092\u8a08\u7b97\u3067\u304d\u307e\u305b\u3093\u3067\u3057\u305f\u3002\u518d\u5ea6\u3001\u8a66\u3057\u3066\u3082\u3001\u3053\u306e\u554f\u984c\u304c\u767a\u751f\u3059\u308b\u5834\u5408\u306b\u306f\u7ba1\u7406\u8005\u306b\u304a\u554f\u3044\u5408\u308f\u305b\u304f\u3060\u3055\u3044\u3002
 expire.order.process.in.checkoutconfirm.for.confirm=\u6ce8\u6587\u30d7\u30ed\u30bb\u30b9\u306e\u6709\u52b9\u671f\u9650\u304c\u5207\u308c\u307e\u3057\u305f\u3002\u518d\u5ea6\u3001\u6ce8\u6587\u3057\u306a\u304a\u3057\u3066\u304f\u3060\u3055\u3044\u3002
 could.not.find.cart.info.in.checkoutconfirm=\u30ab\u30fc\u30c8\u5185\u306e\u5546\u54c1\u60c5\u5831\u3092\u53d6\u5f97\u3067\u304d\u307e\u305b\u3093\u3067\u3057\u305f\u3002\u30ab\u30fc\u30c8\u306e\u671f\u9650\u304c\u5207\u308c\u305f\u53ef\u80fd\u6027\u304c\u3042\u308a\u307e\u3059\u3002\u518d\u5ea6\u3001\u8a66\u3057\u3066\u3082\u3001\u3053\u306e\u554f\u984c\u304c\u767a\u751f\u3059\u308b\u5834\u5408\u306b\u306f\u7ba1\u7406\u8005\u306b\u304a\u554f\u3044\u5408\u308f\u305b\u304f\u3060\u3055\u3044\u3002
 could.not.store.order=\u6ce8\u6587\u78ba\u5b9a\u51e6\u7406\u3067\u30a8\u30e9\u30fc\u304c\u767a\u751f\u3057\u307e\u3057\u305f\u3002\u7ba1\u7406\u8005\u306b\u304a\u554f\u3044\u5408\u308f\u305b\u304f\u3060\u3055\u3044\u3002

Modified: pompei/portlets/pompei-core/trunk/src/main/resources/fee.dicon
===================================================================
--- pompei/portlets/pompei-core/trunk/src/main/resources/fee.dicon	2007-10-16 07:54:33 UTC (rev 630)
+++ pompei/portlets/pompei-core/trunk/src/main/resources/fee.dicon	2007-10-16 13:49:34 UTC (rev 631)
@@ -2,4 +2,6 @@
 <!DOCTYPE components PUBLIC "-//SEASAR//DTD S2Container 2.4//EN" "http://www.seasar.org/dtd/components24.dtd">
 <components>
   <component name="defaultDeliveryMethodCalculator" class="jp.sf.pal.pompei.fee.impl.DefaultDeliveryMethodCalculator"/>
+  <component name="cashOnDeliveryPaymentCalculator" class="jp.sf.pal.pompei.fee.impl.CashOnDeliveryPaymentCalculator"/>
+  <component name="bankPaymentCalculator" class="jp.sf.pal.pompei.fee.impl.BankPaymentCalculator"/>
 </components>

Modified: pompei/portlets/pompei-core/trunk/src/main/webapp/WEB-INF/db/create_table.sql
===================================================================
--- pompei/portlets/pompei-core/trunk/src/main/webapp/WEB-INF/db/create_table.sql	2007-10-16 07:54:33 UTC (rev 630)
+++ pompei/portlets/pompei-core/trunk/src/main/webapp/WEB-INF/db/create_table.sql	2007-10-16 13:49:34 UTC (rev 631)
@@ -95,7 +95,8 @@
 CREATE TABLE PAYMENT_METHOD (
        PAYMENT_METHOD_ID INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY (START WITH 100, INCREMENT BY 1)
      , CODE VARCHAR(16) NOT NULL
-     , FEE DECIMAL(14, 6) NOT NULL
+     , OBJECT_NAME VARCHAR(128) NOT NULL
+     , STATUS INTEGER NOT NULL
      , SORT_ORDER INTEGER NOT NULL
      , DATE_ADDED TIMESTAMP NOT NULL
      , LAST_MODIFIED TIMESTAMP NOT NULL

Modified: pompei/portlets/pompei-core/trunk/src/main/webapp/view/user/checkout/paymentSelect.html
===================================================================
--- pompei/portlets/pompei-core/trunk/src/main/webapp/view/user/checkout/paymentSelect.html	2007-10-16 07:54:33 UTC (rev 630)
+++ pompei/portlets/pompei-core/trunk/src/main/webapp/view/user/checkout/paymentSelect.html	2007-10-16 13:49:34 UTC (rev 631)
@@ -112,6 +112,7 @@
               </tr>
             </table>
             <br />
+            <div id="isCreditcard">
             <div style="font-size: 14pt;font-weight: bold;"><span style="color:#ff9900;">3-3.</span> クレジットカード情報を入力してください (カード払いの場合のみ)</div>
             <table style="border-top: 1px solid silver;border-bottom: 1px solid silver;width: 100%;">
               <tr>
@@ -173,6 +174,7 @@
               </tr>
             </table>
             <br/>
+            </div>
             <br/>
             <div style="width:100%;text-align: center;">
               <input id="doNext" type="button" value="ご注文内容の確認へ" onclick="location.href='./userAddressSelection.html'" />


pal-cvs メーリングリストの案内
Back to archive index
--- pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/bsentity/BsPaymentMethod.java	2007-10-16 07:54:33 UTC (rev 630)
+++ pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/bsentity/BsPaymentMethod.java	2007-10-16 13:49:34 UTC (rev 631)
@@ -14,7 +14,7 @@
  *     PAYMENT_METHOD_ID
  * 
  * [column-property]
- *     PAYMENT_METHOD_ID, CODE, FEE, SORT_ORDER, DATE_ADDED, LAST_MODIFIED
+ *     PAYMENT_METHOD_ID, CODE, OBJECT_NAME, STATUS, SORT_ORDER, DATE_ADDED, LAST_MODIFIED
  * 
  * [foreign-property]
  *     
@@ -63,9 +63,12 @@
     /** The value of code. VARCHAR(16) : NotNull */
     protected String _code;
 
-    /** The value of fee. DECIMAL(14) : NotNull */
-    protected java.math.BigDecimal _fee;
+    /** The value of objectName. VARCHAR(128) : NotNull */
+    protected String _objectName;
 
+    /** The value of status. INTEGER : NotNull */
+    protected java.math.BigDecimal _status;
+
     /** The value of sortOrder. INTEGER : NotNull */
     protected java.math.BigDecimal _sortOrder;
 
@@ -188,31 +191,55 @@
         this._code = code;
     }
 
-    /** Column Annotation for S2Dao. DECIMAL(14) : NotNull */
-    public static final String fee_COLUMN = "FEE";
+    /** Column Annotation for S2Dao. VARCHAR(128) : NotNull */
+    public static final String objectName_COLUMN = "OBJECT_NAME";
 
     /**
-     * Get the value of fee. <br />
-     * {DECIMAL(14) : NotNull}
+     * Get the value of objectName. <br />
+     * {VARCHAR(128) : NotNull}
      * 
-     * @return The value of fee. (Nullable)
+     * @return The value of objectName. (Nullable)
      */
-    public java.math.BigDecimal getFee() {
-        return _fee;
+    public String getObjectName() {
+        return _objectName;
     }
 
     /**
-     * Set the value of fee. <br />
-     * {DECIMAL(14) : NotNull}
+     * Set the value of objectName. <br />
+     * {VARCHAR(128) : NotNull}
      * 
      * @param fee The value of fee. (Nullable)
      */
-    public void setFee(java.math.BigDecimal fee) {
-        _modifiedProperties.addPropertyName("fee");
-        this._fee = fee;
+    public void setObjectName(String objectName) {
+        _modifiedProperties.addPropertyName("objectName");
+        this._objectName = objectName;
     }
 
     /** Column Annotation for S2Dao. INTEGER : NotNull */
+    public static final String status_COLUMN = "STATUS";
+
+    /**
+     * Get the value of status. <br />
+     * {INTEGER : NotNull}
+     * 
+     * @return The value of status. (Nullable)
+     */
+    public java.math.BigDecimal getStatus() {
+        return _status;
+    }
+
+    /**
+     * Set the value of status. <br />
+     * {INTEGER : NotNull}
+     * 
+     * @param status The value of status. (Nullable)
+     */
+    public void setStatus(java.math.BigDecimal status) {
+        _modifiedProperties.addPropertyName("status");
+        this._status = status;
+    }
+
+    /** Column Annotation for S2Dao. INTEGER : NotNull */
     public static final String sortOrder_COLUMN = "SORT_ORDER";
 
     /**
@@ -288,16 +315,16 @@
     // ===================================================================================
     //                                                                     Classify Method
     //                                                                     ===============
-            
+              
     // ===================================================================================
     //                                                        Classification Determination
     //                                                        ============================
-            
+              
 
     // ===================================================================================
     //                                                               Classification Getter
     //                                                               =====================
-            
+              
 
     // ===================================================================================
     //                                                                       Foreign Table
@@ -464,7 +491,8 @@
 
         sb.append(delimiter).append(getPaymentMethodId());
         sb.append(delimiter).append(getCode());
-        sb.append(delimiter).append(getFee());
+        sb.append(delimiter).append(getObjectName());
+        sb.append(delimiter).append(getStatus());
         sb.append(delimiter).append(getSortOrder());
         sb.append(delimiter).append(getDateAdded());
         sb.append(delimiter).append(getLastModified());
@@ -188,31 +191,55 @@
      * 
-     * @param fee The value of fee. (Nullable)
+     * @param objectName The value of objectName. (Nullable)
      */

Modified: pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/bsentity/dbmeta/PaymentMethodDbm.java
===================================================================
--- pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/bsentity/dbmeta/PaymentMethodDbm.java	2007-10-16 07:54:33 UTC (rev 630)
+++ pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/bsentity/dbmeta/PaymentMethodDbm.java	2007-10-16 13:49:34 UTC (rev 631)
@@ -16,7 +16,7 @@
  *     PAYMENT_METHOD_ID
  * 
  * [column-property]
- *     PAYMENT_METHOD_ID, CODE, FEE, SORT_ORDER, DATE_ADDED, LAST_MODIFIED
+ *     PAYMENT_METHOD_ID, CODE, OBJECT_NAME, STATUS, SORT_ORDER, DATE_ADDED, LAST_MODIFIED
  * 
  * [foreign-property]
  *     
@@ -97,8 +97,10 @@
     public static final String DB_NAME_PAYMENT_METHOD_ID = "PAYMENT_METHOD_ID";
     /** Db-name of CODE. VARCHAR(16) : NotNull */
     public static final String DB_NAME_CODE = "CODE";
-    /** Db-name of FEE. DECIMAL(14) : NotNull */
-    public static final String DB_NAME_FEE = "FEE";
+    /** Db-name of OBJECT_NAME. VARCHAR(128) : NotNull */
+    public static final String DB_NAME_OBJECT_NAME = "OBJECT_NAME";
+    /** Db-name of STATUS. INTEGER : NotNull */
+    public static final String DB_NAME_STATUS = "STATUS";
     /** Db-name of SORT_ORDER. INTEGER : NotNull */
     public static final String DB_NAME_SORT_ORDER = "SORT_ORDER";
     /** Db-name of DATE_ADDED. TIMESTAMP : NotNull */
@@ -110,8 +112,10 @@
     public static final String COLUMN_DB_NAME_OF_PaymentMethodId = "PAYMENT_METHOD_ID";
     /** @deprecated Deprecated! So use DB_NAME_Code. */
     public static final String COLUMN_DB_NAME_OF_Code = "CODE";
-    /** @deprecated Deprecated! So use DB_NAME_Fee. */
-    public static final String COLUMN_DB_NAME_OF_Fee = "FEE";
+    /** @deprecated Deprecated! So use DB_NAME_ObjectName. */
+    public static final String COLUMN_DB_NAME_OF_ObjectName = "OBJECT_NAME";
+    /** @deprecated Deprecated! So use DB_NAME_Status. */
+    public static final String COLUMN_DB_NAME_OF_Status = "STATUS";
     /** @deprecated Deprecated! So use DB_NAME_SortOrder. */
     public static final String COLUMN_DB_NAME_OF_SortOrder = "SORT_ORDER";
     /** @deprecated Deprecated! So use DB_NAME_DateAdded. */
@@ -126,8 +130,10 @@
     public static final String PROPERTY_NAME_paymentMethodId = "paymentMethodId";
     /** Prop-name(JavaBeansRule) of code. VARCHAR(16) : NotNull */
     public static final String PROPERTY_NAME_code = "code";
-    /** Prop-name(JavaBeansRule) of fee. DECIMAL(14) : NotNull */
-    public static final String PROPERTY_NAME_fee = "fee";
+    /** Prop-name(JavaBeansRule) of objectName. VARCHAR(128) : NotNull */
+    public static final String PROPERTY_NAME_objectName = "objectName";
+    /** Prop-name(JavaBeansRule) of status. INTEGER : NotNull */
+    public static final String PROPERTY_NAME_status = "status";
     /** Prop-name(JavaBeansRule) of sortOrder. INTEGER : NotNull */
     public static final String PROPERTY_NAME_sortOrder = "sortOrder";
     /** Prop-name(JavaBeansRule) of dateAdded. TIMESTAMP : NotNull */
@@ -142,8 +148,10 @@
     public static final String CAP_PROP_NAME_PaymentMethodId = "PaymentMethodId";
     /** Cap-prop-name of code. VARCHAR(16) : NotNull */
     public static final String CAP_PROP_NAME_Code = "Code";
-    /** Cap-prop-name of fee. DECIMAL(14) : NotNull */
-    public static final String CAP_PROP_NAME_Fee = "Fee";
+    /** Cap-prop-name of objectName. VARCHAR(128) : NotNull */
+    public static final String CAP_PROP_NAME_ObjectName = "ObjectName";
+    /** Cap-prop-name of status. INTEGER : NotNull */
+    public static final String CAP_PROP_NAME_Status = "Status";
     /** Cap-prop-name of sortOrder. INTEGER : NotNull */
     public static final String CAP_PROP_NAME_SortOrder = "SortOrder";
     /** Cap-prop-name of dateAdded. TIMESTAMP : NotNull */
@@ -155,8 +163,10 @@
     public static final String COLUMN_CAP_PROP_NAME_OF_PaymentMethodId = "PaymentMethodId";
     /** @deprecated Deprecated! So use CAP_PROP_NAME_Code. */
     public static final String COLUMN_CAP_PROP_NAME_OF_Code = "Code";
-    /** @deprecated Deprecated! So use CAP_PROP_NAME_Fee. */
-    public static final String COLUMN_CAP_PROP_NAME_OF_Fee = "Fee";
+    /** @deprecated Deprecated! So use CAP_PROP_NAME_ObjectName. */
+    public static final String COLUMN_CAP_PROP_NAME_OF_ObjectName = "ObjectName";
+    /** @deprecated Deprecated! So use CAP_PROP_NAME_Status. */
+    public static final String COLUMN_CAP_PROP_NAME_OF_Status = "Status";
     /** @deprecated Deprecated! So use CAP_PROP_NAME_SortOrder. */
     public static final String COLUMN_CAP_PROP_NAME_OF_SortOrder = "SortOrder";
     /** @deprecated Deprecated! So use CAP_PROP_NAME_DateAdded. */
@@ -171,8 +181,10 @@
     public static final String UNCAP_PROP_NAME_paymentMethodId = "paymentMethodId";
     /** Uncap-prop-name of code. VARCHAR(16) : NotNull */
     public static final String UNCAP_PROP_NAME_code = "code";
-    /** Uncap-prop-name of fee. DECIMAL(14) : NotNull */
-    public static final String UNCAP_PROP_NAME_fee = "fee";
+    /** Uncap-prop-name of objectName. VARCHAR(128) : NotNull */
+    public static final String UNCAP_PROP_NAME_objectName = "objectName";
+    /** Uncap-prop-name of status. INTEGER : NotNull */
+    public static final String UNCAP_PROP_NAME_status = "status";
     /** Uncap-prop-name of sortOrder. INTEGER : NotNull */
     public static final String UNCAP_PROP_NAME_sortOrder = "sortOrder";
     /** Uncap-prop-name of dateAdded. TIMESTAMP : NotNull */
@@ -184,8 +196,10 @@
     public static final String COLUMN_UNCAP_PROP_NAME_OF_PaymentMethodId = "paymentMethodId";
     /** @deprecated Deprecated! So use UNCAP_PROP_NAME_Code. */
     public static final String COLUMN_UNCAP_PROP_NAME_OF_Code = "code";
-    /** @deprecated Deprecated! So use UNCAP_PROP_NAME_Fee. */
-    public static final String COLUMN_UNCAP_PROP_NAME_OF_Fee = "fee";
+    /** @deprecated Deprecated! So use UNCAP_PROP_NAME_ObjectName. */
+    public static final String COLUMN_UNCAP_PROP_NAME_OF_ObjectName = "objectName";
+    /** @deprecated Deprecated! So use UNCAP_PROP_NAME_Status. */
+    public static final String COLUMN_UNCAP_PROP_NAME_OF_Status = "status";
     /** @deprecated Deprecated! So use UNCAP_PROP_NAME_SortOrder. */
     public static final String COLUMN_UNCAP_PROP_NAME_OF_SortOrder = "sortOrder";
     /** @deprecated Deprecated! So use UNCAP_PROP_NAME_DateAdded. */
@@ -226,7 +240,8 @@
 
         map.put(DB_NAME_PAYMENT_METHOD_ID.toLowerCase(), PROPERTY_NAME_paymentMethodId);
         map.put(DB_NAME_CODE.toLowerCase(), PROPERTY_NAME_code);
-        map.put(DB_NAME_FEE.toLowerCase(), PROPERTY_NAME_fee);
+        map.put(DB_NAME_OBJECT_NAME.toLowerCase(), PROPERTY_NAME_objectName);
+        map.put(DB_NAME_STATUS.toLowerCase(), PROPERTY_NAME_status);
         map.put(DB_NAME_SORT_ORDER.toLowerCase(), PROPERTY_NAME_sortOrder);
         map.put(DB_NAME_DATE_ADDED.toLowerCase(), PROPERTY_NAME_dateAdded);
         map.put(DB_NAME_LAST_MODIFIED.toLowerCase(), PROPERTY_NAME_lastModified);
@@ -246,7 +261,8 @@
 
         map.put(PROPERTY_NAME_paymentMethodId.toLowerCase(), DB_NAME_PAYMENT_METHOD_ID);
         map.put(PROPERTY_NAME_code.toLowerCase(), DB_NAME_CODE);
-        map.put(PROPERTY_NAME_fee.toLowerCase(), DB_NAME_FEE);
+        map.put(PROPERTY_NAME_objectName.toLowerCase(), DB_NAME_OBJECT_NAME);
+        map.put(PROPERTY_NAME_status.toLowerCase(), DB_NAME_STATUS);
         map.put(PROPERTY_NAME_sortOrder.toLowerCase(), DB_NAME_SORT_ORDER);
         map.put(PROPERTY_NAME_dateAdded.toLowerCase(), DB_NAME_DATE_ADDED);
         map.put(PROPERTY_NAME_lastModified.toLowerCase(), DB_NAME_LAST_MODIFIED);
@@ -268,7 +284,8 @@
 
         map.put(DB_NAME_PAYMENT_METHOD_ID, CAP_PROP_NAME_PaymentMethodId);
         map.put(DB_NAME_CODE, CAP_PROP_NAME_Code);
-        map.put(DB_NAME_FEE, CAP_PROP_NAME_Fee);
+        map.put(DB_NAME_OBJECT_NAME, CAP_PROP_NAME_ObjectName);
+        map.put(DB_NAME_STATUS, CAP_PROP_NAME_Status);
         map.put(DB_NAME_SORT_ORDER, CAP_PROP_NAME_SortOrder);
         map.put(DB_NAME_DATE_ADDED, CAP_PROP_NAME_DateAdded);
         map.put(DB_NAME_LAST_MODIFIED, CAP_PROP_NAME_LastModified);
@@ -290,7 +307,8 @@
 
         map.put(DB_NAME_PAYMENT_METHOD_ID, UNCAP_PROP_NAME_paymentMethodId);
         map.put(DB_NAME_CODE, UNCAP_PROP_NAME_code);
-        map.put(DB_NAME_FEE, UNCAP_PROP_NAME_fee);
+        map.put(DB_NAME_OBJECT_NAME, UNCAP_PROP_NAME_objectName);
+        map.put(DB_NAME_STATUS, UNCAP_PROP_NAME_status);
         map.put(DB_NAME_SORT_ORDER, UNCAP_PROP_NAME_sortOrder);
         map.put(DB_NAME_DATE_ADDED, UNCAP_PROP_NAME_dateAdded);
         map.put(DB_NAME_LAST_MODIFIED, UNCAP_PROP_NAME_lastModified);
@@ -312,7 +330,8 @@
 
         map.put(CAP_PROP_NAME_PaymentMethodId, DB_NAME_PAYMENT_METHOD_ID);
         map.put(CAP_PROP_NAME_Code, DB_NAME_CODE);
-        map.put(CAP_PROP_NAME_Fee, DB_NAME_FEE);
+        map.put(CAP_PROP_NAME_ObjectName, DB_NAME_OBJECT_NAME);
+        map.put(CAP_PROP_NAME_Status, DB_NAME_STATUS);
         map.put(CAP_PROP_NAME_SortOrder, DB_NAME_SORT_ORDER);
         map.put(CAP_PROP_NAME_DateAdded, DB_NAME_DATE_ADDED);
         map.put(CAP_PROP_NAME_LastModified, DB_NAME_LAST_MODIFIED);
@@ -334,7 +353,8 @@
 
         map.put(CAP_PROP_NAME_PaymentMethodId, UNCAP_PROP_NAME_paymentMethodId);
         map.put(CAP_PROP_NAME_Code, UNCAP_PROP_NAME_code);
-        map.put(CAP_PROP_NAME_Fee, UNCAP_PROP_NAME_fee);
+        map.put(CAP_PROP_NAME_ObjectName, UNCAP_PROP_NAME_objectName);
+        map.put(CAP_PROP_NAME_Status, UNCAP_PROP_NAME_status);
         map.put(CAP_PROP_NAME_SortOrder, UNCAP_PROP_NAME_sortOrder);
         map.put(CAP_PROP_NAME_DateAdded, UNCAP_PROP_NAME_dateAdded);
         map.put(CAP_PROP_NAME_LastModified, UNCAP_PROP_NAME_lastModified);
@@ -356,7 +376,8 @@
 
         map.put(UNCAP_PROP_NAME_paymentMethodId, DB_NAME_PAYMENT_METHOD_ID);
         map.put(UNCAP_PROP_NAME_code, DB_NAME_CODE);
-        map.put(UNCAP_PROP_NAME_fee, DB_NAME_FEE);
+        map.put(UNCAP_PROP_NAME_objectName, DB_NAME_OBJECT_NAME);
+        map.put(UNCAP_PROP_NAME_status, DB_NAME_STATUS);
         map.put(UNCAP_PROP_NAME_sortOrder, DB_NAME_SORT_ORDER);
         map.put(UNCAP_PROP_NAME_dateAdded, DB_NAME_DATE_ADDED);
         map.put(UNCAP_PROP_NAME_lastModified, DB_NAME_LAST_MODIFIED);
@@ -378,7 +399,8 @@
 
         map.put(UNCAP_PROP_NAME_paymentMethodId, CAP_PROP_NAME_PaymentMethodId);
         map.put(UNCAP_PROP_NAME_code, CAP_PROP_NAME_Code);
-        map.put(UNCAP_PROP_NAME_fee, CAP_PROP_NAME_Fee);
+        map.put(UNCAP_PROP_NAME_objectName, CAP_PROP_NAME_ObjectName);
+        map.put(UNCAP_PROP_NAME_status, CAP_PROP_NAME_Status);
         map.put(UNCAP_PROP_NAME_sortOrder, CAP_PROP_NAME_SortOrder);
         map.put(UNCAP_PROP_NAME_dateAdded, CAP_PROP_NAME_DateAdded);
         map.put(UNCAP_PROP_NAME_lastModified, CAP_PROP_NAME_LastModified);
@@ -592,7 +614,8 @@
         final java.util.List<ColumnInfo> columnInfoList = new java.util.ArrayList<ColumnInfo>();
         columnInfoList.add(columnPaymentMethodId());
         columnInfoList.add(columnCode());
-        columnInfoList.add(columnFee());
+        columnInfoList.add(columnObjectName());
+        columnInfoList.add(columnStatus());
         columnInfoList.add(columnSortOrder());
         columnInfoList.add(columnDateAdded());
         columnInfoList.add(columnLastModified());
@@ -651,7 +674,7 @@
      * @deprecated Please use getColumnInfoList()
      */
     public String getColumnDbNameCommaString() {
-        return "PAYMENT_METHOD_ID, CODE, FEE, SORT_ORDER, DATE_ADDED, LAST_MODIFIED";
+        return "PAYMENT_METHOD_ID, CODE, OBJECT_NAME, STATUS, SORT_ORDER, DATE_ADDED, LAST_MODIFIED";
     }
 
     /**
@@ -667,12 +690,18 @@
         return new ColumnInfo(this, "CODE", "code", String.class, false);
     }
     /**
      * @return Column information of fee. (NotNull)
      */
-    public ColumnInfo columnFee() {
-        return new ColumnInfo(this, "FEE", "fee", java.math.BigDecimal.class, false);
+    public ColumnInfo columnObjectName() {
+        return new ColumnInfo(this, "OBJECT_NAME", "objectName", String.class, false);
     }
     /**
+     * @return Column information of status. (NotNull)
+     */
+    public ColumnInfo columnStatus() {
+        return new ColumnInfo(this, "STATUS", "status", java.math.BigDecimal.class, false);
+    }
+    /**
      * @return Column information of sortOrder. (NotNull)
      */
     public ColumnInfo columnSortOrder() {
@@ -832,7 +861,8 @@
 
         public RelationTrace columnPaymentMethodId() { return fixTrace(_relationList, PaymentMethodDbm.getInstance().columnPaymentMethodId()); }
         public RelationTrace columnCode() { return fixTrace(_relationList, PaymentMethodDbm.getInstance().columnCode()); }
-        public RelationTrace columnFee() { return fixTrace(_relationList, PaymentMethodDbm.getInstance().columnFee()); }
+        public RelationTrace columnObjectName() { return fixTrace(_relationList, PaymentMethodDbm.getInstance().columnObjectName()); }
+        public RelationTrace columnStatus() { return fixTrace(_relationList, PaymentMethodDbm.getInstance().columnStatus()); }
         public RelationTrace columnSortOrder() { return fixTrace(_relationList, PaymentMethodDbm.getInstance().columnSortOrder()); }
         public RelationTrace columnDateAdded() { return fixTrace(_relationList, PaymentMethodDbm.getInstance().columnDateAdded()); }
         public RelationTrace columnLastModified() { return fixTrace(_relationList, PaymentMethodDbm.getInstance().columnLastModified()); }
@@ -908,7 +938,8 @@
 
         if (analyzer.init("PAYMENT_METHOD_ID", "paymentMethodId", "paymentMethodId")) { myEntity.setPaymentMethodId(analyzer.analyzeNumber(java.math.BigDecimal.class)); };
         if (analyzer.init("CODE", "code", "code")) { myEntity.setCode(analyzer.analyzeString(String.class)); };
-        if (analyzer.init("FEE", "fee", "fee")) { myEntity.setFee(analyzer.analyzeNumber(java.math.BigDecimal.class)); };
+        if (analyzer.init("OBJECT_NAME", "objectName", "objectName")) { myEntity.setObjectName(analyzer.analyzeString(String.class)); };
+        if (analyzer.init("STATUS", "status", "status")) { myEntity.setStatus(analyzer.analyzeNumber(java.math.BigDecimal.class)); };
         if (analyzer.init("SORT_ORDER", "sortOrder", "sortOrder")) { myEntity.setSortOrder(analyzer.analyzeNumber(java.math.BigDecimal.class)); };
         if (analyzer.init("DATE_ADDED", "dateAdded", "dateAdded")) { myEntity.setDateAdded(analyzer.analyzeDate(java.sql.Timestamp.class)); };
         if (analyzer.init("LAST_MODIFIED", "lastModified", "lastModified")) { myEntity.setLastModified(analyzer.analyzeDate(java.sql.Timestamp.class)); };
@@ -986,7 +1017,8 @@
         final StringBuffer sb = new StringBuffer();
         helpAppendingColumnValueString(sb, delimiter, equal, "PAYMENT_METHOD_ID", myEntity.getPaymentMethodId());
         helpAppendingColumnValueString(sb, delimiter, equal, "CODE", myEntity.getCode());
-        helpAppendingColumnValueString(sb, delimiter, equal, "FEE", myEntity.getFee());
+        helpAppendingColumnValueString(sb, delimiter, equal, "OBJECT_NAME", myEntity.getObjectName());
+        helpAppendingColumnValueString(sb, delimiter, equal, "STATUS", myEntity.getStatus());
         helpAppendingColumnValueString(sb, delimiter, equal, "SORT_ORDER", myEntity.getSortOrder());
         helpAppendingColumnValueString(sb, delimiter, equal, "DATE_ADDED", myEntity.getDateAdded());
         helpAppendingColumnValueString(sb, delimiter, equal, "LAST_MODIFIED", myEntity.getLastModified());
@@ -1046,7 +1078,8 @@
         final java.util.Map<String, Object> valueMap = new java.util.LinkedHashMap<String, Object>();
         valueMap.put("PAYMENT_METHOD_ID", myEntity.getPaymentMethodId());
         valueMap.put("CODE", myEntity.getCode());
-        valueMap.put("FEE", myEntity.getFee());
+        valueMap.put("OBJECT_NAME", myEntity.getObjectName());
+        valueMap.put("STATUS", myEntity.getStatus());
         valueMap.put("SORT_ORDER", myEntity.getSortOrder());
         valueMap.put("DATE_ADDED", myEntity.getDateAdded());
         valueMap.put("LAST_MODIFIED", myEntity.getLastModified());
@@ -1074,7 +1107,8 @@
         final java.util.Map<String, String> valueMap = new java.util.LinkedHashMap<String, String>();
         valueMap.put("PAYMENT_METHOD_ID", helpGettingColumnStringValue(myEntity.getPaymentMethodId()));
         valueMap.put("CODE", helpGettingColumnStringValue(myEntity.getCode()));
-        valueMap.put("FEE", helpGettingColumnStringValue(myEntity.getFee()));
+        valueMap.put("OBJECT_NAME", helpGettingColumnStringValue(myEntity.getObjectName()));
+        valueMap.put("STATUS", helpGettingColumnStringValue(myEntity.getStatus()));
         valueMap.put("SORT_ORDER", helpGettingColumnStringValue(myEntity.getSortOrder()));
         valueMap.put("DATE_ADDED", helpGettingColumnStringValue(myEntity.getDateAdded()));
         valueMap.put("LAST_MODIFIED", helpGettingColumnStringValue(myEntity.getLastModified()));
@@ -1102,9 +1136,9 @@
     public String getPreparedInsertClause(PreparedInsertClauseOption preparedInsertClauseOption) {
         if (preparedInsertClauseOption.getTablePrefix() != null) {
             final String tablePrefix = preparedInsertClauseOption.getTablePrefix();
-            return "insert into " + tablePrefix + "PAYMENT_METHOD(PAYMENT_METHOD_ID, CODE, FEE, SORT_ORDER, DATE_ADDED, LAST_MODIFIED) values(? , ? , ? , ? , ? , ? )";
+            return "insert into " + tablePrefix + "PAYMENT_METHOD(PAYMENT_METHOD_ID, CODE, OBJECT_NAME, STATUS, SORT_ORDER, DATE_ADDED, LAST_MODIFIED) values(? , ? , ? , ? , ? , ? , ? )";
         }
-        return "insert into PAYMENT_METHOD(PAYMENT_METHOD_ID, CODE, FEE, SORT_ORDER, DATE_ADDED, LAST_MODIFIED) values(? , ? , ? , ? , ? , ? )";
+        return "insert into PAYMENT_METHOD(PAYMENT_METHOD_ID, CODE, OBJECT_NAME, STATUS, SORT_ORDER, DATE_ADDED, LAST_MODIFIED) values(? , ? , ? , ? , ? , ? , ? )";
     }
 
     // ===================================================================================
@@ -667,12 +690,18 @@
     }
     /**
-     * @return Column information of fee. (NotNull)
+     * @return Column information of objectName. (NotNull)
      */

Modified: pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/cbean/cq/bs/AbstractBsPaymentMethodCQ.java
===================================================================
--- pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/cbean/cq/bs/BsPaymentMethodCQ.java	2007-10-16 07:54:33 UTC (rev 630)
+++ pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/cbean/cq/bs/BsPaymentMethodCQ.java	2007-10-16 13:49:34 UTC (rev 631)
@@ -91,24 +91,42 @@
     }
   
     /**
      * Include select-column of fee as mine.
      * Alias name is java-name of this column.
      * Be careful to whether your table have the same column.
      */
-    public void includeAsMine_Fee() {
-        registerIncludedSelectColumn("Fee", getRealColumnName("FEE"));
+    public void includeAsMine_ObjectName() {
+        registerIncludedSelectColumn("ObjectName", getRealColumnName("OBJECT_NAME"));
     }
 
     /**
      * Include select-column of fee as mine.
      * 
      * @param aliasName Alias name. {select columnName as aliasName from ...} This should not contain comma. (NotNull)
      */
-    public void includeAsMine_Fee(String aliasName) {
-        registerIncludedSelectColumn(aliasName, getRealColumnName("FEE"));
+    public void includeAsMine_ObjectName(String aliasName) {
+        registerIncludedSelectColumn(aliasName, getRealColumnName("OBJECT_NAME"));
     }
   
     /**
+     * Include select-column of status as mine.
+     * Alias name is java-name of this column.
+     * Be careful to whether your table have the same column.
+     */
+    public void includeAsMine_Status() {
+        registerIncludedSelectColumn("Status", getRealColumnName("STATUS"));
+    }
+
+    /**
+     * Include select-column of status as mine.
+     * 
+     * @param aliasName Alias name. {select columnName as aliasName from ...} This should not contain comma. (NotNull)
+     */
+    public void includeAsMine_Status(String aliasName) {
+        registerIncludedSelectColumn(aliasName, getRealColumnName("STATUS"));
+    }
+  
+    /**
      * Include select-column of sortOrder as mine.
      * Alias name is java-name of this column.
      * Be careful to whether your table have the same column.
@@ -318,48 +336,90 @@
     }
       
     // /- - - - - - - - - - - - - - - - - - - - - - -
-    //   Column = [FEE]
+    //   Column = [OBJECT_NAME]
     // - - - - - - - - -/
 
-    /** The attribute of fee. */
-    protected ConditionValue _fee;
+    /** The attribute of objectName. */
+    protected ConditionValue _objectName;
 
     /**
-     * Get the value of fee.
+     * Get the value of objectName.
      * 
-     * @return The value of fee.
+     * @return The value of objectName.
      */
-    public ConditionValue getFee() {
-        if (_fee == null) {
-            _fee = new ConditionValue();
+    public ConditionValue getObjectName() {
+        if (_objectName == null) {
+            _objectName = new ConditionValue();
         }
-        return _fee;
+        return _objectName;
     }
 
-    protected ConditionValue getCValueFee() {
-        return getFee();
+    protected ConditionValue getCValueObjectName() {
+        return getObjectName();
     }
 
                                                   
     /**
      * Add order-by of fee as ASC.
      * 
      * @return this. (NotNull)
      */
-    public BsPaymentMethodCQ addOrderBy_Fee_Asc() {
-        getSqlClause().registerOrderBy(getRealColumnName(COL_FEE), null, true);return this;
+    public BsPaymentMethodCQ addOrderBy_ObjectName_Asc() {
+        getSqlClause().registerOrderBy(getRealColumnName(COL_OBJECT_NAME), null, true);return this;
     }
 
     /**
      * Add order-by of fee as DESC.
      * 
      * @return this. (NotNull)
      */
-    public BsPaymentMethodCQ addOrderBy_Fee_Desc() {
-        getSqlClause().registerOrderBy(getRealColumnName(COL_FEE), null, false);return this;
+    public BsPaymentMethodCQ addOrderBy_ObjectName_Desc() {
+        getSqlClause().registerOrderBy(getRealColumnName(COL_OBJECT_NAME), null, false);return this;
     }
       
     // /- - - - - - - - - - - - - - - - - - - - - - -
+    //   Column = [STATUS]
+    // - - - - - - - - -/
+
+    /** The attribute of status. */
+    protected ConditionValue _status;
+
+    /**
+     * Get the value of status.
+     * 
+     * @return The value of status.
+     */
+    public ConditionValue getStatus() {
+        if (_status == null) {
+            _status = new ConditionValue();
+        }
+        return _status;
+    }
+
+    protected ConditionValue getCValueStatus() {
+        return getStatus();
+    }
+
+                                                  
+    /**
+     * Add order-by of status as ASC.
+     * 
+     * @return this. (NotNull)
+     */
+    public BsPaymentMethodCQ addOrderBy_Status_Asc() {
+        getSqlClause().registerOrderBy(getRealColumnName(COL_STATUS), null, true);return this;
+    }
+
+    /**
+     * Add order-by of status as DESC.
+     * 
+     * @return this. (NotNull)
+     */
+    public BsPaymentMethodCQ addOrderBy_Status_Desc() {
+        getSqlClause().registerOrderBy(getRealColumnName(COL_STATUS), null, false);return this;
+    }
+      
+    // /- - - - - - - - - - - - - - - - - - - - - - -
     //   Column = [SORT_ORDER]
     // - - - - - - - - -/
 
@@ -91,24 +91,42 @@
   
     /**
-     * Include select-column of fee as mine.
+     * Include select-column of objectName as mine.
      * Alias name is java-name of this column.
      * Be careful to whether your table have the same column.
@@ -91,24 +91,42 @@
 
     /**
-     * Include select-column of fee as mine.
+     * Include select-column of objectName as mine.
      * 
      * @param aliasName Alias name. {select columnName as aliasName from ...} This should not contain comma. (NotNull)
@@ -318,48 +336,90 @@
                                                   
     /**
-     * Add order-by of fee as ASC.
+     * Add order-by of objectName as ASC.
      * 
      * @return this. (NotNull)
@@ -318,48 +336,90 @@
 
     /**
-     * Add order-by of fee as DESC.
+     * Add order-by of objectName as DESC.
      * 
      * @return this. (NotNull)

Modified: pompei/portlets/pompei-core/trunk/src/main/java/jp/sf/pal/pompei/cbean/cq/ciq/PaymentMethodCIQ.java
===================================================================